import React, { useState, useEffect } from 'react';
import { Form, Icon, Input, Button, DatePicker, Select, Card, Row, Col, Pagination, Alert, Table, Avatar, Radio, Modal, Descriptions } from 'antd';
import moment from 'moment';
import request from '../../../utils/request';
import apis from '../../../services/apis';
import Styles from './style.less';


const { Option } = Select;
// eslint-disable-next-line @typescript-eslint/no-unused-vars
const { Meta } = Card;

/**
 * 调整归属
 *  (废弃， 后面研究)
 *
 * @param {*} props
 * @returns
 */
class ModalTable extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
       dataSource: { records: [] },
       visibleData: { visible: false, customerId: '', realtyConsultant: '' },
    }
  }

  // 挂载之后
  componentDidMount() {
    this.getList({ pageNumber: 1, pageSize: 5 })
  }

  componentDidUpdate(preProps, preState) {
    if (this.props.visibleData.customerId !== preState.visibleData.customerId) {
      this.getList({ pageNumber: 1, pageSize: 5 })
      this.setState({ visibleData: this.props.visibleData });
    }
  }

  // 弹框确定按钮
  // eslint-disable-next-line react/sort-comp
  handleOk() {
    this.setState({ visibleData: { visible: false, customerId: '', realtyConsultant: '' } })
  }

  // 弹框取消按钮
  handleCancel() {
    this.setState({ visibleData: { visible: false, customerId: '', realtyConsultant: '' } })
  }

  getList(params) {
    // 网路请求
    request({ ...apis.customer.consultant, params: { ...params } }).then(res => {
      this.setState({ dataSource: res })
    }).catch(err => {
      // eslint-disable-next-line no-unused-expressions
      <Alert
        style={{
          marginBottom: 24,
        }}
        message={err}
        type="error"
        showIcon
      />
    })
  }

   // 分页
  onChange(pageNum) {
    this.getList({ pageNumber: pageNum, pageSize: 5 })
  }

  // 提交
  submitGm() {
    const { url, method } = apis.customer.recommendEdit
    const tempUrl = url.substring(0, url.lastIndexOf('id')).concat(this.state.visibleData.customerId)

    // 网路请求
    request({ url: tempUrl, method, data: { ...this.state.visibleData } }).then(res => {
      this.handleCancel()
    }).catch(err => {
      // eslint-disable-next-line no-unused-expressions
      <Alert
        style={{
          marginBottom: 24,
        }}
        message={err}
        type="error"
        showIcon
      />
    })
  }

  render() {
    const columns = [
      {
        title: '姓名',
        dataIndex: 'name',
        key: 'name',
      },
      {
        title: '电话',
        dataIndex: 'phone',
        key: 'phone',
      },
      {
        title: '部门',
        dataIndex: 'department',
        key: 'department',
      },
      {
        title: '岗位',
        dataIndex: 'post',
        key: 'post',
      },
      {
        title: '操作',
        dataIndex: 'personId',
        key: 'personId',
        // eslint-disable-next-line no-nested-ternary
        render: (_, record) => <><Button className={Styles.SubmitButton} onClick={() => this.submitGm()}>确定</Button></>,
      },
    ]
    return (
      <>
        <Modal
            title="选择置业顾问"
            destroyOnClose="true"
            footer={null}
            visible={this.state.visibleData.visible}
            // onOk={() => this.handleOk()}
            onCancel={(e) => this.handleCancel(e)}
          >
            <Table dataSource={this.state.dataSource.records} columns={columns} pagination={{ total: this.state.dataSource.total, onChange: e => this.onChange(e) }} />
          </Modal>
      </>
    );
  }
}

/**
 *
 *
 * @param {*} props
 * @returns
 */
function body(props) {
  const { getFieldDecorator } = props.form

  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [dataSource, setDataSource] = useState({ records: [] })

  // 默认私客
    // eslint-disable-next-line react-hooks/rules-of-hooks
  const [customerType, setCustomerType] = useState('private')

  // 调整归属 ============  start
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [gVisibleData, setGVisibleData] = useState({ visible: false, customerId: '', realtyConsultant: '' })

  // 调整归属 ============= end

  // eslint-disable-next-line react-hooks/rules-of-hooks
  useEffect(() => {
    getList({ pageNumber: 1, pageSize: 10, customerType })
  }, [])

  function getList(params) {
    // 网路请求
    request({ ...apis.customer.customerRecommend, params: { ...params } }).then(res => {
      setDataSource(res)
    }).catch(err => {
      // eslint-disable-next-line no-unused-expressions
      <Alert
        style={{
          marginBottom: 24,
        }}
        message={err}
        type="error"
        showIcon
      />
    })
  }

  // 提交事件
  function handleSubmit(e) {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        getList({ pageNum: 1, pageSize: 10, customerType, ...values })
      }
    });
  }

  // Change 事件
  function handleSelectChange(e) {
    // eslint-disable-next-line no-console
    console.log(e)
  }

  // 分页
  function onChange(pageNum) {
    // eslint-disable-next-line react-hooks/rules-of-hooks
      getList({ pageNumber: pageNum, pageSize: 10, customerType })
  }

  // 私客/公客切换
  function radioButtonHandleSizeChange(e) {
    const { value } = e.target
    setCustomerType(value)
    getList({ pageNumber: 1, pageSize: 10, customerType: value })
  }

  // 调整归属 ============ start
  // 调整归属 显示
  function gM(row) {
    setGVisibleData({ visible: true, customerId: row.customerId, realtyConsultant: row.realtyConsultant })
  }
  // 调整归属 ============ end

  const columns = [
    {
      title: '头像',
      dataIndex: 'picture',
      key: 'picture',
      render: (_, record) => <Avatar shape="square" src={customerType === 'private' ? record.picture : record.avatarurl } size={64} icon="user" />,
    },
    {
      title: '姓名',
      dataIndex: 'name',
      key: 'name',
      // eslint-disable-next-line no-nested-ternary
      render: (_, record) => <><sapn>{ customerType === 'private' ? record.name : record.nickname }</sapn></>,
    },
    {
      title: '电话',
      dataIndex: 'phone',
      key: 'phone',
    },
    {
      title: '性别',
      dataIndex: 'sex',
      key: 'sex',
      // eslint-disable-next-line no-nested-ternary
      render: (_, record) => <><sapn>{ record.sex === 1 ? '男' : record.sex === 2 ? '女' : '未知' }</sapn></>,
    },
    {
      title: '置业顾问',
      dataIndex: 'consultantName',
      key: 'consultantName',
      // eslint-disable-next-line no-nested-ternary
      render: (_, record) => (
        <>
          <sapn>{ record.consultantName }</sapn>
          <br/>
          <sapn>{ record.consultTel }</sapn>
        </>
      ),
    },
    {
      title: '客户状态',
      dataIndex: 'reportRecommendStatus',
      key: 'reportRecommendStatus',
       // eslint-disable-next-line no-nested-ternary
       render: (_, record) => <><sapn>{ record.reportRecommendStatus === 0 ? '为报备' : record.reportRecommendStatus === 1 ? '报备' : record.reportRecommendStatus === 2 ? '推荐' : '' }</sapn></>,
    },
    {
      title: '操作',
      dataIndex: 'customerId',
      key: 'customerId',
      // eslint-disable-next-line no-nested-ternary
      render: (_, record) => (
        <>
          <sapn className={ customerType === 'private' ? Styles.text : Styles.displayS }>变更状态</sapn>
          &nbsp;&nbsp;
          <sapn className={ customerType === 'private' ? Styles.text : Styles.displayS } onClick={() => gM(record)}>调整归属</sapn>
          <br/>
          <sapn className={ Styles.text }>查看详情</sapn>
          &nbsp;&nbsp;
          <sapn className={ Styles.text }>积分记录</sapn>
        </>
      ),
    },
  ]

  return (
    <>
      <Form layout="inline" onSubmit={e => handleSubmit(e, props)}>
        <Form.Item>
          {getFieldDecorator('buildingId')(
            <Select style={{ width: '180px' }} placeholder="意向项目" onChange={handleSelectChange}>
              <Option value="male">male</Option>
            </Select>,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('reportRecommendStatus')(
            <Select style={{ width: '180px' }} placeholder="状态" onChange={handleSelectChange}>
              <Option value={0}>未报备</Option>
              <Option value={1}>报备</Option>
              <Option value={2}>推荐</Option>
            </Select>,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('name')(
            <Input
              prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
              placeholder="姓名"
            />,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('tel')(
            <Input
              prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
              placeholder="电话"
            />,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('consultName')(
            <Input placeholder="置业顾问" />,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('consultTel')(
            <Input placeholder="置业顾问电话" />,
          )}
        </Form.Item>
        <Form.Item>
          <Button type="primary" htmlType="submit" className={Styles.SubmitButton}>
            搜索
          </Button>
        </Form.Item>
      </Form>

       <div style={{ marginTop: '20px', marginBottom: '20px' }}>
        <Radio.Group value={customerType} onChange={radioButtonHandleSizeChange} buttonStyle="solid">
            <Radio.Button value="private">私客</Radio.Button>
            <Radio.Button value="public">公客</Radio.Button>
        </Radio.Group>
       </div>
      <Table dataSource={dataSource.records} columns={columns} pagination={{ total: dataSource.total, onChange }} />

        {/* 调整归属 */}
        <ModalTable visibleData={gVisibleData} />

    </>
  );
}

const WrappedBody = Form.create({ name: 'body' })(body);

export default WrappedBody
